Package: geneticae
Title: Statistical Tools for the Analysis of Multi Environment
        Agronomic Trials
Version: 1.0.1
Authors@R: c(
  person(given = "Julia",
         family = "Angelini",
         role = c("aut", "cre"),
         email = "jangelini_93@hotmail.com",
         comment = c(ORCID = "0000-0002-5815-1771")
         ),
  person(given = "Marcos",
         family = "Prunello",
         role = c("aut"),
         email = "marcosprunello@gmail.com",
         comment = c(ORCID = "0000-0002-9611-527X")
         ),
  person(given = "Gerardo",
         family = "Cervigni",
         role = c("aut")
         )
  )
Description: Provides tools for the analysis of multi-environment agronomic 
    trials, with a specific focus on plant breeding experiments. 
    Implements the Additive Main effects and Multiplicative Interaction 
    (AMMI) model (Gauch, 1992, ISBN:9780444892409) and the Site Regression 
    (SREG) model (Cornelius, 1996, <doi:10.1201/9780367802226>). To ensure 
    reliable results even with outliers or missing data, it includes robust 
    versions of AMMI (Rodrigues et al., 2016, 
    <doi:10.1093/bioinformatics/btv533>) and SREG (Angelini et al., 2022, 
    <doi:10.1080/15427528.2022.2051217>). Furthermore, the package offers 
    advanced imputation techniques for multi-environment data, covering 
    classical methodologies (Arciniegas-Alarcón et al., 2014, 
    <doi:10.2478/bile-2014-0006>) and recently published imputation methods 
    for MET data (Angelini et al., 2024, <doi:10.1007/s10681-024-03344-z>).
License: GPL-2
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Imports: stats, ggforce, ggplot2, scales, MASS, pcaMethods, rrcov,
        dplyr, missMDA, tidyr, rlang, corpcor
Suggests: agridat, spelling, knitr, rmarkdown, patchwork, testthat
VignetteBuilder: knitr
Depends: R (>= 2.12.0)
URL: https://jangelini.github.io/geneticae/,
        https://github.com/jangelini/geneticae
BugReports: https://github.com/jangelini/geneticae/issues
Language: en-US
NeedsCompilation: no
Packaged: 2026-04-20 22:45:40 UTC; julia
Author: Julia Angelini [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5815-1771>),
  Marcos Prunello [aut] (ORCID: <https://orcid.org/0000-0002-9611-527X>),
  Gerardo Cervigni [aut]
Maintainer: Julia Angelini <jangelini_93@hotmail.com>
Repository: CRAN
Date/Publication: 2026-04-21 10:52:14 UTC
Built: R 4.5.2; ; 2026-04-21 19:21:24 UTC; unix
