# Generated by roxygen2: do not edit by hand

export(BiplotImputfun)
export(EM.SREG)
export(imputation)
export(rAMMIModel)
export(rAMMIPlot)
export(rSREGModel)
export(rSREGPlot)
import(ggplot2)
importFrom(MASS,ginv)
importFrom(MASS,rlm)
importFrom(corpcor,fast.svd)
importFrom(dplyr,"%>%")
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,group_by)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(ggforce,geom_arc)
importFrom(ggforce,geom_circle)
importFrom(ggplot2,aes)
importFrom(ggplot2,arrow)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,layer_scales)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_size_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(grDevices,chull)
importFrom(grid,unit)
importFrom(missMDA,imputePCA)
importFrom(pcaMethods,loadings)
importFrom(pcaMethods,pca)
importFrom(pcaMethods,robustSvd)
importFrom(pcaMethods,scores)
importFrom(rlang,sym)
importFrom(rrcov,CovControlMrcd)
importFrom(rrcov,PcaCov)
importFrom(rrcov,PcaGrid)
importFrom(rrcov,PcaHubert)
importFrom(rrcov,PcaLocantore)
importFrom(rrcov,PcaProj)
importFrom(rrcov,getEigenvalues)
importFrom(rrcov,getLoadings)
importFrom(rrcov,getScores)
importFrom(scales,alpha)
importFrom(scales,squish)
importFrom(stats,as.formula)
importFrom(stats,lm)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(tidyr,pivot_wider)
