#'Clones from the PLRV population
#'
#'@description  resistance study to PLRV (Patato Leaf Roll Virus) causing leaf
#'curl. 28 genotypes were experimented at 6 locations in Peru. Each clone was
#'evaluated three times in each environment, and yield, plant weight and plot were
#'registered.
#'
#'@name plrv
#'@docType data
#'@usage data(plrv)
#'
#'@format Data frame with 504 observations and 6 variables (genotype,
#'   locality, repetition, weightPlant, weightPlot and yield).
#'
#'@keywords datasets
#'
#'@references Felipe de Mendiburu (2020). agricolae: Statistical Procedures for
#'  Agricultural Research. R package version 1.3-2.
#'  \url{https://CRAN.R-project.org/package=agricolae}
#'
#' @examples
#' library(geneticae)
#' data(plrv)
#' str(plrv)
#'
NULL
