if (getRversion() >= "2.15.1")  {
  utils::globalVariables(
    c("X1", "X2" ,"end" ,"label", "radio", "start", "x0" ,"x1_x", "x1_y" ,"y0","value", "variable", "genotype", "Data", "Component1", "Component2","env", "mean_resp")
  )
}
